@@ -1026,8 +1026,8 @@ static int import_e5res(const char *filename, VAR **vars, ATTS *atts)
 
 	      for ( i = 0; i < nlev; i++ )
 		{
-		  start[0] = 0;      start[1] = i;;
-		  count[0] = nvals;  count[1] = 1;;     
+		  start[0] = 0;      start[1] = i;
+		  count[0] = nvals;  count[1] = 1;  
 
 		  nce(nc_inq_varid(nc_file_id, name, &nc_var_id));
 		  nce(nc_get_vara_double(nc_file_id, nc_var_id, start, count, (*vars)[varid].ptr+i*nvals));
@@ -1572,9 +1572,8 @@ void *Echam5ini(void *argument)
       if ( vdate == 0 )
 	{
 	  vdate = 19890101;
-	  vtime = 1200;
+	  vtime = 120000;
 	}
-      vtime *= 100;
 
       for ( recID = 0; recID < nrecs; recID++ )
 	{
@@ -1594,7 +1593,6 @@ void *Echam5ini(void *argument)
 	export_e5res(cdoStreamName(1), vars, nvars);
       else
 	cdoAbort("Operator not implemented!");
-     
     }
   else
     {
