@@ -234,7 +234,7 @@ int defSinusoidalGrid(int nx, int ny, double xmin, double xmax, double ymin, dou
 
   for ( i = 0; i < ny; ++i )
     {
-      yvals[i] = ymax - i*dx - dx/2;;
+      yvals[i] = ymax - i*dx - dx/2;
       /* printf("y[%d]=%g\n", i, yvals[i]); */
     }
 
@@ -271,7 +271,7 @@ int defLaeaGrid(int nx, int ny, double xmin, double xmax, double ymin, double ym
 
   for ( i = 0; i < ny; ++i )
     {
-      yvals[i] = ymax - i*dx - dx/2;;
+      yvals[i] = ymax - i*dx - dx/2;
       /* printf("y[%d]=%g\n", i, yvals[i]); */
     }
 
@@ -469,8 +469,31 @@ int read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
 
   if ( cdoVerbose ) cdoPrint("  Size: xsize=%d  ysize=%d", xsize, ysize);
 
+  /* some CM-SAF files have incorrect entries for some metadata. */
+  /* these are corrected in the following sections. */
   if ( strcmp(proj.ellipsoid, "WSG-84") == 0 ) strcpy(proj.ellipsoid, "WGS-84");
 
+  if ( strcmp(proj.name, "sinusoidal") != 0  && 
+       nx == xsize && ny == ysize &&
+       (int)region.xmin == -8887500 &&  (int)region.xmax == 8887500 && 
+       (int)region.ymin  -8887500 && (int)region.ymax == 8887500 && 
+       (int)region.dx == 15000 && (int)region.dy  == 15000 )
+  {
+      if ( cdoVerbose ) cdoPrint("Replacing incorrect projection parameters for sinusoidal products:");
+      strcpy(proj.ellipsoid, "WGS-84");
+      strcpy(proj.name, "sinusoidal");
+      proj.parameter[0] = 0.0; 
+      proj.parameter[1] = 0.0;
+      proj.parameter[2] = 0.0; 
+      proj.parameter[3] = 0.0;  
+      proj.parameter[4] = -99.99;      
+      proj.parameter[5] = -99.99;          
+      if ( cdoVerbose ) 
+	  cdoPrint("proj1 = %g, proj2 = %g, proj3 = %g, proj4 = %g,",  
+		   proj.parameter[0], proj.parameter[1],  
+		   proj.parameter[2], proj.parameter[3]);
+  }
+
   if ( nx == xsize && ny == ysize && 
        strcmp(proj.name, "sinusoidal") == 0 && 
        strcmp(proj.ellipsoid, "WGS-84") == 0  )
@@ -527,17 +550,14 @@ int read_geolocation(hid_t loc_id, int nx, int ny, int lprojtype)
 static
 int read_region(hid_t loc_id, int nx, int ny)
 {
-  static char func[] = "read_region";
+  //static char func[] = "read_region";
   int gridID = -1;
-  hsize_t		memb_size[1] = {4};
   hid_t grp_id;
-  hid_t proj_id, region_id;
-  hid_t proj_tid, region_tid;
+  hid_t region_id;
+  hid_t region_tid;
   hid_t str64_tid, str128_tid, fltarr_tid;
   herr_t     status;
   hsize_t dims;
-  int xsize, ysize;
-  hid_t      file, dataset, datatype; /* Handles */
   typedef struct region_t {
     double area_extent[4];
     int xsize;
@@ -985,9 +1005,23 @@ void read_dataset(hid_t loc_id, const char *name, void *opdata)
 
       if ( ftype )
 	{
-	  status = H5Dread(dset_id, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL, H5P_DEFAULT, array);
-	  if ( status < 0 )
-	    cdoAbort("Reading of NATIVE_DOUBLE variable %s failed!", varname);
+	  if ( dtype == DATATYPE_FLT32 )
+	    {
+	      float *farray;
+	      int i;
+	      farray = (float *) malloc(gridsize*nt*sizeof(float));
+	      status = H5Dread(dset_id, H5T_NATIVE_FLOAT, H5S_ALL, H5S_ALL, H5P_DEFAULT, farray);
+	      if ( status < 0 )
+		cdoAbort("Reading of NATIVE_FLOAT variable %s failed!", varname);
+	      for ( i = 0; i < gridsize*nt; ++i ) array[i] = farray[i];
+	      free(farray);
+	    }
+	  else
+	    {
+	      status = H5Dread(dset_id, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL, H5P_DEFAULT, array);
+	      if ( status < 0 )
+		cdoAbort("Reading of NATIVE_DOUBLE variable %s failed!", varname);
+	    }
 	}
       else
 	{
@@ -1334,8 +1368,8 @@ void dsets_init(dsets_t *dsets)
 
 void *Importcmsaf(void *argument)
 {
-#if  defined  (HAVE_LIBHDF5)
   static char func[] = "Importcmsaf";
+#if  defined  (HAVE_LIBHDF5)
   int streamID;
   int gridID = -1, zaxisID, taxisID, vlistID;
   int i, offset;
@@ -1350,12 +1384,14 @@ void *Importcmsaf(void *argument)
   dsets_t dsets;
   int vdate, vtime;
   int *vtimes = NULL;
+#endif
 
   cdoInitialize(argument);
 
   if ( cdoDefaultFileType == CDI_UNDEFID )
     cdoDefaultFileType = FILETYPE_NC;
 
+#if  defined  (HAVE_LIBHDF5)
   dsets_init(&dsets);
 
   /* Open an existing file. */
@@ -1385,7 +1421,7 @@ void *Importcmsaf(void *argument)
     {
       vtimes = (int *) malloc(nt*sizeof(int));
       
-      for ( i = 0; i < nt; ++i ) vtimes[i] = i*100 + 45;
+      for ( i = 0; i < nt; ++i ) vtimes[i] = i*10000 + 45*100;
 
       if ( dsets.obj[ivar].time )
 	{
@@ -1394,8 +1430,8 @@ void *Importcmsaf(void *argument)
 
 	  for ( i = 0; i < nt; ++i )
 	    {
-	      itime = (int)strtol(pline, &pline, 10);
-	      if ( itime < 0 || itime > 2400 )
+	      itime = ((int)strtol(pline, &pline, 10))*100;
+	      if ( itime < 0 || itime > 240000 )
 		{
 		  cdoWarning("Wrong time string!");
 		  break;
@@ -1568,7 +1604,7 @@ void *Importcmsaf(void *argument)
 
   cdoFinish();
 #else
-  cdoWarning("HDF5 support not compiled in!");
+  cdoAbort("HDF5 support not compiled in!");
 #endif
 
   return (0);
