@@ -44,9 +44,9 @@ void *Inttime(void *argument)
   int taxisID1, taxisID2;
   int vdate, vtime;
   int offset;
-  int ijulinc, incperiod = 0, incunit = 3600;
+  int ijulinc, incperiod = 0, incunit = 3600, tunit = TUNIT_HOUR;
   int calendar;
-  int year, month, day, hour, minute;
+  int year, month, day, hour, minute, second;
   int *recVarID, *recLevelID;
   int **nmiss1, **nmiss2, nmiss3;
   const char *datestr, *timestr;
@@ -58,7 +58,7 @@ void *Inttime(void *argument)
 
   cdoInitialize(argument);
 
-  operatorInputArg("date,time<,increment> (format YYYY-MM-DD,hh:mm)");
+  operatorInputArg("date,time<,increment> (format YYYY-MM-DD,hh:mm:ss)");
   if ( operatorArgc() < 2 ) cdoAbort("Not enough arguments!");
 
   datestr = operatorArgv()[0];
@@ -70,6 +70,7 @@ void *Inttime(void *argument)
     }
   else
     {
+      year = 1; month = 1; day = 1;
       sscanf(datestr, "%d-%d-%d", &year, &month, &day);
       vdate = encode_date(year, month, day);
     }
@@ -80,8 +81,9 @@ void *Inttime(void *argument)
     }
   else
     {
-      sscanf(timestr, "%d:%d", &hour, &minute);
-      vtime = encode_time(hour, minute);
+      hour = 0; minute = 0; second = 0;
+      sscanf(timestr, "%d:%d:%d", &hour, &minute, &second);
+      vtime = encode_time(hour, minute, second);
     }
 
   if ( operatorArgc() == 3 )
@@ -93,11 +95,12 @@ void *Inttime(void *argument)
       len = strlen(unit);
       if ( len )
 	{
-	  if      ( memcmp(unit, "minutes", len) == 0 ) incunit =    60;
-	  else if ( memcmp(unit, "hours", len)   == 0 ) incunit =  3600;
-	  else if ( memcmp(unit, "days", len)    == 0 ) incunit = 86400;
-	  else if ( memcmp(unit, "months", len)  == 0 ) incunit =     1;
-	  else if ( memcmp(unit, "years", len)   == 0 ) incunit =    12;
+	  if      ( memcmp(unit, "seconds", len) == 0 ) {incunit =     1; tunit = TUNIT_SECOND;}
+	  else if ( memcmp(unit, "minutes", len) == 0 ) {incunit =    60; tunit = TUNIT_MINUTE;}
+	  else if ( memcmp(unit, "hours", len)   == 0 ) {incunit =  3600; tunit = TUNIT_HOUR;  }
+	  else if ( memcmp(unit, "days", len)    == 0 ) {incunit = 86400; tunit = TUNIT_DAY;   }
+	  else if ( memcmp(unit, "months", len)  == 0 ) {incunit =     1; tunit = TUNIT_MONTH; }
+	  else if ( memcmp(unit, "years", len)   == 0 ) {incunit =    12; tunit = TUNIT_YEAR;  }
 	  else cdoAbort("unsupported time unit >%s<", unit);
 	}
     }
@@ -218,9 +221,10 @@ void *Inttime(void *argument)
 		  cdoPrint("juldate2 %f", juldate_to_seconds(juldate2));
 		  */
 		  decode_date(vdate, &year, &month, &day);
-		  decode_time(vtime, &hour, &minute);
-		  cdoPrint("%4.4d-%2.2d-%2.2d %2.2d:%2.2d  %f  %d",
-			   year, month, day, hour, minute, juldate_to_seconds(juldate), calendar);
+		  decode_time(vtime, &hour, &minute, &second);
+		  cdoPrint(DATE_FORMAT" "TIME_FORMAT"  %f  %d",
+			   year, month, day, hour, minute, second,
+			   juldate_to_seconds(juldate), calendar);
 		}
 
 	      taxisDefVdate(taxisID2, vdate);
@@ -279,7 +283,7 @@ void *Inttime(void *argument)
 
 	  if ( ijulinc == 0 ) break;
 
-	  if ( incunit == 1 || incunit == 12 )
+	  if ( tunit == TUNIT_MONTH || tunit == TUNIT_YEAR )
 	    {
 	      juldate_decode(calendar, juldate, &vdate, &vtime);
 
