@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2007-2008 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
+  Copyright (C) 2007-2009 Uwe Schulzweida, Uwe.Schulzweida@zmaw.de
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -39,18 +39,20 @@
 #include <stdio.h>
 
 
-void hetaeta(int ltq, int ngp, int *imiss,
-	     int nlev1, double *ah1, double *bh1,
-             double *fis1, double *ps1, 
-             double *t1, double *q1,
-             int nlev2, double *ah2, double *bh2, 
-             double *fis2, double *ps2, 
-             double *t2, double *q2,
-	     int nvars, double **vars1, double **vars2,
-	     double *tscor, double *pscor, double *secor);
+void hetaeta(int ltq, int ngp, const int *imiss,
+	     int nlev1, const double *ah1, const double *bh1,
+             const double *fis1, const double *ps1, 
+             const double *t1, const double *q1,
+             int nlev2, const double *ah2, const double *bh2, 
+             const double *fis2, double * restrict ps2, 
+             double * restrict t2, double * restrict q2,
+	     int nvars, double **vars1, double ** restrict vars2,
+	     double * restrict tscor, double * restrict pscor,
+	     double * restrict secor);
 
 
-static void setmissval(int nvals, int *imiss, double missval, double *array)
+static 
+void setmissval(int nvals, int *imiss, double missval, double *array)
 {
   int i;
 
@@ -63,10 +65,63 @@ static void setmissval(int nvals, int *imiss, double missval, double *array)
     }
 }
 
- 
-static void minmax(int nvals, double *array, int *imiss, double *minval, double *maxval)
+static
+void corr_hum(int gridsize, double *q, double q_min)
 {
-  int i;
+  long i;
+
+  for ( i = 0; i < (long) gridsize; ++i )
+    {
+      if ( q[i] < q_min ) q[i] = q_min;
+    }
+}
+ 
+static
+long ncctop(long nlev, long nlevp1, double *vct_a, double *vct_b)
+{
+  /*
+    Description:
+    Defines highest level *ncctop* where condensation is allowed.
+    
+    Author:
+  
+    E. Roeckner, MPI, October 2001
+  */
+  /* local variables */
+  long nctop = 0;
+  long jk;
+  double    za, zb, zph[nlevp1], zp[nlev];
+  double    cptop  =  1000.;   /* min. pressure level for cond. */
+
+  /* half level pressure values, assuming 101320. Pa surface pressure */
+
+  for ( jk = 0; jk < (long) nlevp1; ++jk )
+    {
+      za = vct_a[jk];
+      zb = vct_b[jk];
+      zph[jk] = za + zb*101320.;
+    }
+
+  /* full level pressure */
+
+  for ( jk = 0; jk < (long)nlev; ++jk )
+    zp[jk] = (zph[jk] + zph[jk+1])*0.5;
+
+  /* search for pressure level cptop (Pa) */
+
+  for ( jk = 0; jk < (long)nlev; ++jk )
+    {
+      nctop = jk;
+      if ( zp[jk] >= cptop ) break;
+    }
+
+  return (nctop);
+}
+
+static
+void minmax(int nvals, double *array, int *imiss, double *minval, double *maxval)
+{
+  long i;
   double xmin =  DBL_MAX;
   double xmax = -DBL_MAX;
 
@@ -131,10 +186,16 @@ void *Remapeta(void *argument)
   int lfis2 = FALSE;
   int varids[MAX_VARS3D];
   int *imiss = NULL;
+  long nctop;
   double *array = NULL;
   double **vars1 = NULL, **vars2 = NULL;
   double minval, maxval;
   double missval = 0;
+  double ps_min =  20000, ps_max = 120000;
+  double fis_min = -100000, fis_max = 100000;
+  double t_min = 170, t_max = 320;
+  double q_min = 0, q_max = 0.1;
+  double cconst = 1.E-6;
 
   cdoInitialize(argument);
 
@@ -508,7 +569,7 @@ void *Remapeta(void *argument)
 
 	  minmax(ngp, ps1, imiss, &minval, &maxval);
 
-	  if ( minval < 20000 || maxval > 150000 )
+	  if ( minval < ps_min || maxval > ps_max )
 	    cdoWarning("Surface pressure out of range (min=%g max=%g)!", minval, maxval);
 
 	  if ( minval < -1.e10 || maxval > 1.e10 )
@@ -518,7 +579,7 @@ void *Remapeta(void *argument)
 
 	  minmax(ngp, fis1, imiss, &minval, &maxval);
 
-	  if ( minval < -100000 || maxval > 100000 )
+	  if ( minval < fis_min || maxval > fis_max )
 	    cdoWarning("Orography out of range (min=%g max=%g)!", minval, maxval);
 
 	  if ( minval < -1.e10 || maxval > 1.e10 )
@@ -528,6 +589,37 @@ void *Remapeta(void *argument)
       if ( lfis2 == FALSE )
 	for ( i = 0; i < ngp; i++ ) fis2[i] = fis1[i];
 
+      if ( ltq )
+	{
+	  varID = tempID;
+	  nlevel = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
+	  for ( levelID = 0; levelID < nlevel; levelID++ )
+	    {
+	      gridsize = gridInqSize(vlistInqVarGrid(vlistID2, varID));
+	      offset   = gridsize*levelID;
+	      single2  = t1 + offset;
+
+	      minmax(ngp, single2, imiss, &minval, &maxval);
+	      if ( minval < t_min || maxval > t_max )
+		cdoWarning("Output temperature at level %d out of range (min=%g max=%g)!",
+			   levelID+1, minval, maxval);
+	    }
+
+	  varID = sqID;
+	  nlevel = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID));
+	  for ( levelID = 0; levelID < nlevel; levelID++ )
+	    {
+	      gridsize = gridInqSize(vlistInqVarGrid(vlistID2, varID));
+	      offset   = gridsize*levelID;
+	      single2  = q1 + offset;
+
+	      minmax(ngp, single2, imiss, &minval, &maxval);
+	      if ( minval < q_min || maxval > q_max )
+		cdoWarning("Output humidity at level %d out of range (min=%g max=%g)!",
+			   levelID+1, minval, maxval);
+	    }
+	}
+
       if ( nvars3D || ltq )
 	hetaeta(ltq, ngp, imiss,
 		nlevh1, a1, b1,
@@ -539,6 +631,8 @@ void *Remapeta(void *argument)
 		nvars3D, vars1, vars2,
 		tscor, pscor, secor);
 
+      nctop = ncctop((long) nlevh2, (long) nlevh2+1, a2, b2);
+
       if ( geopID != -1 )
 	{
 	  varID   = geopID;
@@ -570,6 +664,11 @@ void *Remapeta(void *argument)
 	      offset   = gridsize*levelID;
 	      single2  = t2 + offset;
 
+	      minmax(ngp, single2, imiss, &minval, &maxval);
+	      if ( minval < t_min || maxval > t_max )
+		cdoWarning("Output temperature at level %d out of range (min=%g max=%g)!",
+			   levelID+1, minval, maxval);
+
 	      if ( gridsize == ngp ) setmissval(ngp, imiss, missval, single2);
 	      streamDefRecord(streamID2, varID, levelID);
 	      streamWriteRecord(streamID2, single2, nmissout);
@@ -583,6 +682,16 @@ void *Remapeta(void *argument)
 	      offset   = gridsize*levelID;
 	      single2  = q2 + offset;
 
+	      corr_hum(gridsize, single2, q_min);
+
+	      if ( levelID < nctop )
+		for ( i = 0; i < gridsize; ++i ) single2[i] = cconst;
+
+	      minmax(ngp, single2, imiss, &minval, &maxval);
+	      if ( minval < q_min || maxval > q_max )
+		cdoWarning("Output humidity at level %d out of range (min=%g max=%g)!",
+			   levelID+1, minval, maxval);
+
 	      if ( gridsize == ngp ) setmissval(ngp, imiss, missval, single2);
 	      streamDefRecord(streamID2, varID, levelID);
 	      streamWriteRecord(streamID2, single2, nmissout);
