@@ -27,6 +27,7 @@
 #include "cdo_int.h"
 #include "pstream.h"
 #include "percentiles.h"
+#include "util.h"
 
 
 void *Seaspctl(void *argument)
@@ -54,6 +55,7 @@ void *Seaspctl(void *argument)
   FIELD field;
   int pn;
   HISTOGRAM_SET *hset = NULL;
+  int season_start;
 
   cdoInitialize(argument);
 
@@ -65,6 +67,8 @@ void *Seaspctl(void *argument)
   if ( pn < 1 || pn > 99 )
     cdoAbort("Illegal argument: percentile number %d is not in the range 1..99!", pn);
 
+  season_start = get_season_start();
+
   streamID1 = streamOpenRead(cdoStreamName(0));
   if ( streamID1 < 0 ) cdiError(streamID1, "Open failed on %s", cdoStreamName(0));
   streamID2 = streamOpenRead(cdoStreamName(1));
@@ -168,17 +172,28 @@ void *Seaspctl(void *argument)
 	  if ( month < 0 || month > 16 )
 	    cdoAbort("Month %d out of range!", month);
 
-	  if ( month <= 12 )
-	    seas = (month % 12) / 3;
+	  newmon = month;
+
+	  if ( season_start == START_DEC )
+	    {
+	      if ( newmon == 12 ) newmon = 0;
+
+	      if ( month <= 12 )
+		seas = (month % 12) / 3;
+	      else
+		seas = month - 13;
+	    }
 	  else
-	    seas = month - 13;
+	    {
+	      if ( month <= 12 )
+		seas = (month - 1) / 3;
+	      else
+		seas = month - 13;
+	    }
 
 	  if ( seas < 0 || seas > 3 )
 	    cdoAbort("Season %d out of range!", seas + 1);
 
-	  newmon = month;
-	  if ( newmon == 12 ) newmon = 0;
-
 	  if ( nsets == 0 )
 	    {
 	      seas0 = seas;
