@@ -69,7 +69,7 @@ void *Seltime(void *argument)
   int lnts1;
   int ncts = 0, nts, it;
   int *selfound = NULL;
-  int year, month, day, hour, minute;
+  int year = 1, month = 1, day = 1, hour = 0, minute = 0, second = 0;
   int nts1 = 0, nts2 = 0;
   int its1 = 0, its2 = 0;
   double selfval = 0, *fltarr, fval = 0;
@@ -88,9 +88,9 @@ void *Seltime(void *argument)
   cdoInitialize(argument);
 
   SELTIMESTEP = cdoOperatorAdd("seltimestep", func_step,     1, "timesteps");
-  SELDATE     = cdoOperatorAdd("seldate",     func_datetime, 1, "start date and end date (format YYYY-MM-DDThh:mm)");
-  SELTIME     = cdoOperatorAdd("seltime",     func_time,     1, "times (format hh:mm)");
-  SELHOUR     = cdoOperatorAdd("selhour",     func_time,   100, "hours");
+  SELDATE     = cdoOperatorAdd("seldate",     func_datetime, 1, "start date and end date (format YYYY-MM-DDThh:mm:ss)");
+  SELTIME     = cdoOperatorAdd("seltime",     func_time,     1, "times (format hh:mm:ss)");
+  SELHOUR     = cdoOperatorAdd("selhour",     func_time, 10000, "hours");
   SELDAY      = cdoOperatorAdd("selday",      func_date,     1, "days");
   SELMON      = cdoOperatorAdd("selmon",      func_date,   100, "months");
   SELYEAR     = cdoOperatorAdd("selyear",     func_date, 10000, "years");
@@ -100,8 +100,8 @@ void *Seltime(void *argument)
   moddat[SELTIMESTEP] =          1;
   /*  moddat[SELDATE]     = 1000000000; */
   moddat[SELDATE]     =          0;
-  moddat[SELTIME]     =      10000;
-  moddat[SELHOUR]     =        100;
+  moddat[SELTIME]     =    1000000;
+  moddat[SELHOUR]     =      10000;
   moddat[SELDAY]      =        100;
   moddat[SELMON]      =        100;
   moddat[SELYEAR]     = 1000000000;
@@ -121,17 +121,22 @@ void *Seltime(void *argument)
     {
       char Seas[3];
       int seas[4] = {FALSE, FALSE, FALSE, FALSE};
-      int ival[4] = {0, 0, 0, 0};
+      int imon[17]; /* 1-16 ! */
+      int ival;
       size_t len;
+      int season_start;
 
+      season_start = get_season_start();
       nsel = operatorArgc();
       if ( isdigit(*operatorArgv()[0]))
 	for ( i = 0; i < nsel; i++ )
 	  {
-	    if      ( atoi(operatorArgv()[i]) == 1 || atoi(operatorArgv()[i]) == 13 ) seas[0] = TRUE;
-	    else if ( atoi(operatorArgv()[i]) == 2 || atoi(operatorArgv()[i]) == 14 ) seas[1] = TRUE;
-	    else if ( atoi(operatorArgv()[i]) == 3 || atoi(operatorArgv()[i]) == 15 ) seas[2] = TRUE;
-	    else if ( atoi(operatorArgv()[i]) == 4 || atoi(operatorArgv()[i]) == 16 ) seas[3] = TRUE;
+	    ival = atoi(operatorArgv()[i]);
+	    if      ( ival == 1 || ival == 13 ) seas[0] = TRUE;
+	    else if ( ival == 2 || ival == 14 ) seas[1] = TRUE;
+	    else if ( ival == 3 || ival == 15 ) seas[2] = TRUE;
+	    else if ( ival == 4 || ival == 16 ) seas[3] = TRUE;
+	    else cdoAbort("Season %d not available!", ival);
 	  }
       else
 	for ( i = 0; i < nsel; i++ )
@@ -139,23 +144,47 @@ void *Seltime(void *argument)
 	    len = strlen(operatorArgv()[i]);
 	    if ( len > 3 ) len = 3;
 	    while ( len-- > 0 ) Seas[len] = toupper(operatorArgv()[i][len]);
-	    if      ( Seas[0] == 'D' && Seas[1] == 'J'  && Seas[2] == 'F' ) seas[0] = TRUE;
-	    else if ( Seas[0] == 'M' && Seas[1] == 'A'  && Seas[2] == 'M' ) seas[1] = TRUE;
-	    else if ( Seas[0] == 'J' && Seas[1] == 'J'  && Seas[2] == 'A' ) seas[2] = TRUE;
-	    else if ( Seas[0] == 'S' && Seas[1] == 'O'  && Seas[2] == 'N' ) seas[3] = TRUE;
+	    if ( season_start == START_DEC )
+	      {
+		if      ( memcmp(Seas, "DJF", 3) == 0 ) seas[0] = TRUE;
+		else if ( memcmp(Seas, "MAM", 3) == 0 ) seas[1] = TRUE;
+		else if ( memcmp(Seas, "JJA", 3) == 0 ) seas[2] = TRUE;
+		else if ( memcmp(Seas, "SON", 3) == 0 ) seas[3] = TRUE;
+		else cdoAbort("Season %s not available!", operatorArgv()[i]);
+	      }
+	    else
+	      {
+		if      ( memcmp(Seas, "JFM", 3) == 0 ) seas[0] = TRUE;
+		else if ( memcmp(Seas, "AMJ", 3) == 0 ) seas[1] = TRUE;
+		else if ( memcmp(Seas, "JAS", 3) == 0 ) seas[2] = TRUE;
+		else if ( memcmp(Seas, "OND", 3) == 0 ) seas[3] = TRUE;
+		else cdoAbort("Season %s not available!", operatorArgv()[i]);
+	      }
 	  }
 
-      nsel = 4;
+      for ( i = 0; i < 17; ++i ) imon[i] = 0;
 
-      if ( seas[0] ) { ival[0] = 12; ival[1] =  1; ival[2] =  2; ival[3] = 13; }
-      if ( seas[1] ) { ival[0] =  3; ival[1] =  4; ival[2] =  5; ival[3] = 14; }
-      if ( seas[2] ) { ival[0] =  6; ival[1] =  7; ival[2] =  8; ival[3] = 15; }
-      if ( seas[3] ) { ival[0] =  9; ival[1] = 10; ival[2] = 11; ival[3] = 16; }
+      if ( season_start == START_DEC )
+	{
+	  if ( seas[0] ) { imon[12]++; imon[ 1]++; imon[ 2]++; imon[13]++; }
+	  if ( seas[1] ) { imon[ 3]++; imon[ 4]++; imon[ 5]++; imon[14]++; }
+	  if ( seas[2] ) { imon[ 6]++; imon[ 7]++; imon[ 8]++; imon[15]++; }
+	  if ( seas[3] ) { imon[ 9]++; imon[10]++; imon[11]++; imon[16]++; }
+	}
+      else
+	{
+	  if ( seas[0] ) { imon[ 1]++; imon[ 2]++; imon[ 3]++; imon[13]++; }
+	  if ( seas[1] ) { imon[ 4]++; imon[ 5]++; imon[ 6]++; imon[14]++; }
+	  if ( seas[2] ) { imon[ 7]++; imon[ 8]++; imon[ 9]++; imon[15]++; }
+	  if ( seas[3] ) { imon[10]++; imon[11]++; imon[12]++; imon[16]++; }
+	}
 
-      listSetInt(ilist, 0, ival[0]);
-      listSetInt(ilist, 1, ival[1]);
-      listSetInt(ilist, 2, ival[2]);
-      listSetInt(ilist, 3, ival[3]);
+      nsel = 0;
+      for ( i = 1; i < 17; ++i )
+	{
+	  if ( imon[i] )
+	    listSetInt(ilist, nsel++, i);
+	}
     }
   else if ( operatorID == SELDATE )
     {
@@ -181,8 +210,18 @@ void *Seltime(void *argument)
 	    }
 	  else
 	    {
-	      year = 0; month = 0; day = 0; hour = 0; minute = 0;
-	      if ( strchr(operatorArgv()[i], 'T') == NULL )
+	      year = 1; month = 1; day = 1; hour = 0; minute = 0, second = 0;
+	      if ( strchr(operatorArgv()[i], 'T') )
+		{
+		  status = sscanf(operatorArgv()[i], "%d-%d-%dT%d:%d:%d",
+				  &year, &month, &day, &hour, &minute, &second);
+		  fval = encode_time(hour, minute, second);
+		  if ( fabs(fval) > 0 ) fval /= 1000000;
+		  fval += encode_date(year, month, day);
+		  listSetFlt(flist, i, fval);
+		  set2 = FALSE;
+		}
+	      else
 		{
 		  status = sscanf(operatorArgv()[i], "%d-%d-%d", &year, &month, &day);
 		  fval = encode_date(year, month, day);
@@ -191,15 +230,6 @@ void *Seltime(void *argument)
 
 		  listSetFlt(flist, i, fval);
 		}
-	      else
-		{
-		  status = sscanf(operatorArgv()[i], "%d-%d-%dT%d:%d", &year, &month, &day, &hour, &minute);
-		  fval = encode_time(hour, minute);
-		  if ( fabs(fval) > 0 ) fval /= 10000;
-		  fval += encode_date(year, month, day);
-		  listSetFlt(flist, i, fval);
-		  set2 = FALSE;
-		}
 	    }
 	}
 
@@ -216,14 +246,14 @@ void *Seltime(void *argument)
       if ( nsel < 1 ) cdoAbort("Not enough arguments!");
       for ( i = 0; i < nsel; i++ )
 	{
-	  if ( strchr(operatorArgv()[i], ':') == NULL )
+	  if ( strchr(operatorArgv()[i], ':') )
 	    {
-	      listSetInt(ilist, i, atoi(operatorArgv()[i]));
+	      sscanf(operatorArgv()[i], "%d:%d:%d", &hour, &minute, &second);
+	      listSetInt(ilist, i, encode_time(hour, minute, second));
 	    }
 	  else
 	    {
-	      sscanf(operatorArgv()[i], "%d:%d", &hour, &minute);
-	      listSetInt(ilist, i, hour*100 + minute);
+	      listSetInt(ilist, i, atoi(operatorArgv()[i]));
 	    }
 	}
     }
@@ -358,7 +388,7 @@ void *Seltime(void *argument)
 	}
       else if ( operfunc == func_datetime )
 	{
-	  selfval = vdate + vtime/10000.;
+	  selfval = vdate + vtime/1000000.;
 	}
 
       if ( operatorID == SELDATE )
