@@ -31,6 +31,7 @@
 #include "pstream.h"
 #include "field.h"
 #include "percentiles.h"
+#include "util.h"
 
 #define  NSEAS       4
 
@@ -60,6 +61,7 @@ void *Yseaspctl(void *argument)
   FIELD field;
   int pn;
   HISTOGRAM_SET *hsets[NSEAS];
+  int season_start;
 
   cdoInitialize(argument);
   cdoOperatorAdd("yseaspctl", func_pctl, 0, NULL);
@@ -70,6 +72,7 @@ void *Yseaspctl(void *argument)
   if ( pn < 1 || pn > 99 )
     cdoAbort("Illegal argument: percentile number %d is not in the range 1..99!", pn);
 
+  season_start = get_season_start();
   for ( seas = 0; seas < NSEAS; seas++ )
     {
       vars1[seas] = NULL;
@@ -132,10 +135,21 @@ void *Yseaspctl(void *argument)
       if ( month < 0 || month > 16 )
 	cdoAbort("Month %d out of range!", month);
 
-      if ( month <= 12 )
-	seas = (month % 12) / 3;
+      if ( season_start == START_DEC )
+	{
+	  if ( month <= 12 )
+	    seas = (month % 12) / 3;
+	  else
+	    seas = month - 13;
+	}
       else
-	seas = month - 13;
+	{
+	  if ( month <= 12 )
+	    seas = (month - 1) / 3;
+	  else
+	    seas = month - 13;
+	}
+
       if ( seas < 0 || seas > 3 )
 	cdoAbort("Season %d out of range!", seas+1);
 
