@@ -36,6 +36,7 @@
 #include "cdo_int.h"
 #include "pstream.h"
 #include "field.h"
+#include "util.h"
 
 
 #define  NSEAS       4
@@ -66,6 +67,7 @@ void *Yseasstat(void *argument)
   double missval;
   FIELD **vars1[NSEAS], **vars2[NSEAS], **samp1[NSEAS];
   FIELD field;
+  int season_start;
 
   cdoInitialize(argument);
 
@@ -80,6 +82,7 @@ void *Yseasstat(void *argument)
   operatorID = cdoOperatorID();
   operfunc = cdoOperatorFunc(operatorID);
 
+  season_start = get_season_start();
   for ( seas = 0; seas < NSEAS; seas++ )
     {
       vars1[seas] = NULL;
@@ -120,12 +123,22 @@ void *Yseasstat(void *argument)
       vtime = taxisInqVtime(taxisID1);
       decode_date(vdate, &year, &month, &day);
       if ( month < 0 || month > 16 )
-	cdoAbort("month %d out of range!", month);
+	cdoAbort("Month %d out of range!", month);
 
-      if ( month <= 12 )
-	seas = (month % 12) / 3;
+      if ( season_start == START_DEC )
+	{
+	  if ( month <= 12 )
+	    seas = (month % 12) / 3;
+	  else
+	    seas = month - 13;
+	}
       else
-	seas = month - 13;
+	{
+	  if ( month <= 12 )
+	    seas = (month - 1) / 3;
+	  else
+	    seas = month - 13;
+	}
 
       if ( seas < 0 || seas > 3 )
 	cdoAbort("Season %d out of range!", seas+1);
