@@ -130,19 +130,25 @@ static void version(void)
 #if defined (COMP_VERSION)
   fprintf(stderr, " version: %s\n", COMP_VERSION);
 #endif
-#if defined (HAVE_LIBSZ) || defined (HAVE_LIBPROJ) || defined (HAVE_LIBDRMAA) || defined (HAVE_LIBCURL)
+#if defined (HAVE_LIBPTHREAD) || defined (HAVE_LIBSZ) || defined (HAVE_LIBPROJ) || defined (HAVE_LIBDRMAA) || defined (HAVE_LIBCURL) || defined (_OPENMP)
   fprintf(stderr, "    with:");
+#if defined (HAVE_LIBPTHREAD)
+  fprintf(stderr, " PTHREADS");
+#endif
 #if defined (HAVE_LIBSZ)
-  fprintf(stderr, " libsz");
+  fprintf(stderr, " SZ");
 #endif
 #if defined (HAVE_LIBPROJ)
-  fprintf(stderr, " libproj");
+  fprintf(stderr, " PROJ.4");
 #endif
 #if defined (HAVE_LIBDRMAA)
-  fprintf(stderr, " libdrmaa");
+  fprintf(stderr, " DRMAA");
 #endif
 #if defined (HAVE_LIBCURL)
-  fprintf(stderr, " libcurl");
+  fprintf(stderr, " CURL");
+#endif
+#if defined (_OPENMP)
+  fprintf(stderr, " OpenMP");
 #endif
   fprintf(stderr, "\n");
 #endif
@@ -155,7 +161,8 @@ static void version(void)
 }
 
 
-static void usage(void)
+static
+void usage(void)
 {
   int id = 0;
   char *name;
@@ -167,8 +174,9 @@ static void usage(void)
   fprintf(stderr, "  Options:\n");
   fprintf(stderr, "    -a             Convert from a relative to an absolute time axis\n");
   fprintf(stderr, "    -b <nbits>     Set the number of bits for the output precision\n");
-  fprintf(stderr, "                   (32/64 for nc, nc2, nc4, srv, ext, ieg; 1 - 32 for grb)\n");
-  fprintf(stderr, "    -f <format>    Format of the output file. (grb, nc, nc2, nc4, srv, ext or ieg)\n");
+  fprintf(stderr, "                   (32/64 for nc/nc2/nc4/srv/ext/ieg; 1 - 32 for grb/grb2)\n");
+  fprintf(stderr, "                   Add L or B to set the byteorder to Little or Big endian\n");
+  fprintf(stderr, "    -f <format>    Format of the output file. (grb, grb2, nc, nc2, nc4, srv, ext or ieg)\n");
   fprintf(stderr, "    -g <grid>      Set default grid name or file. Available grids: \n");
   fprintf(stderr, "                   t<RES>grid, t<RES>spec, r<NX>x<NY>, g<NX>x<NY>, gme<NI>, lon=<LON>_lat=<LAT>\n");
   fprintf(stderr, "    -h             Help information for the operators\n");
@@ -189,6 +197,7 @@ static void usage(void)
   fprintf(stderr, "    -p <prec>      Set the precision of the output data in bytes\n");
   fprintf(stderr, "                   (4/8 for nc, nc2, nc4, srv, ext, ieg; 1/2/3 for grb)\n");
   */
+  fprintf(stderr, "    -Q             Sort netCDF variable names\n");
   fprintf(stderr, "    -R             Convert GRIB data from reduced to regular grid\n");
   fprintf(stderr, "    -r             Convert from an absolute to a relative time axis\n");
   fprintf(stderr, "    -S             Create an extra output stream for the module TIMSTAT. This stream\n");
@@ -217,8 +226,8 @@ static void usage(void)
   fprintf(stderr, "  Report bugs to Uwe.Schulzweida@zmaw.de\n");
 }
 
-
-static void cdoPrintHelp(char *phelp[]/*, char *xoperator*/)
+static
+void cdoPrintHelp(char *phelp[]/*, char *xoperator*/)
 {
   if ( phelp == NULL )
     printf("No help available for this operator!\n");
@@ -239,8 +248,8 @@ static void cdoPrintHelp(char *phelp[]/*, char *xoperator*/)
     }
 }
 
-
-static void cdoSetDebug(int level)
+static
+void cdoSetDebug(int level)
 {
   /*
     level   0: off
@@ -264,11 +273,11 @@ static void cdoSetDebug(int level)
 #endif
 }
 
-
 static int cdoOptind = 1;
 static char *cdoOptarg;
 
-static int cdoGetopt(int argc, char * const argv[], const char *optstring)
+static
+int cdoGetopt(int argc, char * const argv[], const char *optstring)
 {
   static int optpos = 0;
   int optval = -1, value;
@@ -315,12 +324,11 @@ static int cdoGetopt(int argc, char * const argv[], const char *optstring)
   return (optval);
 }
 
-
 #undef  IsBigendian
 #define IsBigendian()  ( u_byteorder.c[sizeof(long) - 1] )
 
-
-static void setDefaultDataType(char *datatypestr)
+static
+void setDefaultDataType(char *datatypestr)
 {
   static union {unsigned long l; unsigned char c[sizeof(long)];} u_byteorder = {1};
   int nbits = -1;
@@ -365,7 +373,7 @@ static void setDefaultDataType(char *datatypestr)
 	  else
 	    {
 	      fprintf(stderr, "Unsupported number of bits %d!\n", nbits);
-	      fprintf(stderr, "Use 32/64 for filetype nc, srv, ext, ieg and 1-32 for grb.\n");
+	      fprintf(stderr, "Use 32/64 for filetype nc/srv/ext/ieg and 1-32 for grb/grb2.\n");
 	      exit(EXIT_FAILURE);
 	    }
 	}
@@ -426,8 +434,8 @@ static void setDefaultDataType(char *datatypestr)
     }
 }
 
-
-static void setDefaultDataTypeByte(char *datatypestr)
+static
+void setDefaultDataTypeByte(char *datatypestr)
 {
   static union {unsigned long l; unsigned char c[sizeof(long)];} u_byteorder = {1};
   int datatype = -1;
@@ -445,7 +453,7 @@ static void setDefaultDataTypeByte(char *datatypestr)
       else
 	{
 	  fprintf(stderr, "Unsupported datatype %d!\n", datatype);
-	  fprintf(stderr, "Use 4/8 for filetype nc, srv, ext, ieg and 1/2/3 for grb.\n");
+	  fprintf(stderr, "Use 4/8 for filetype nc/srv/ext/ieg and 1/2/3 for grb/grb2.\n");
 	  exit(EXIT_FAILURE);
 	}
     }
@@ -470,26 +478,28 @@ static void setDefaultDataTypeByte(char *datatypestr)
     }
 }
 
-
+static
 void setDefaultFileType(char *filetypestr, int labort)
 {
   if ( filetypestr )
     {
       char *ftstr = filetypestr;
 
-      if      ( memcmp(filetypestr, "grb", 3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_GRB; }
-      else if ( memcmp(filetypestr, "nc2", 3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_NC2; }
-      else if ( memcmp(filetypestr, "nc4", 3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_NC4; }
-      else if ( memcmp(filetypestr, "nc",  2)  == 0 ) { ftstr += 2; cdoDefaultFileType = FILETYPE_NC;  }
-      else if ( memcmp(filetypestr, "srv", 3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_SRV; }
-      else if ( memcmp(filetypestr, "ext", 3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_EXT; }
-      else if ( memcmp(filetypestr, "ieg", 3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_IEG; }
+      if      ( memcmp(filetypestr, "grb2", 4)  == 0 ) { ftstr += 4; cdoDefaultFileType = FILETYPE_GRB2;}
+      else if ( memcmp(filetypestr, "grb1", 4)  == 0 ) { ftstr += 4; cdoDefaultFileType = FILETYPE_GRB; }
+      else if ( memcmp(filetypestr, "grb",  3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_GRB; }
+      else if ( memcmp(filetypestr, "nc2",  3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_NC2; }
+      else if ( memcmp(filetypestr, "nc4",  3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_NC4; }
+      else if ( memcmp(filetypestr, "nc",   2)  == 0 ) { ftstr += 2; cdoDefaultFileType = FILETYPE_NC;  }
+      else if ( memcmp(filetypestr, "srv",  3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_SRV; }
+      else if ( memcmp(filetypestr, "ext",  3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_EXT; }
+      else if ( memcmp(filetypestr, "ieg",  3)  == 0 ) { ftstr += 3; cdoDefaultFileType = FILETYPE_IEG; }
       else
 	{
 	  if ( labort )
 	    {
 	      fprintf(stderr, "Unsupported filetype %s!\n", filetypestr);
-	      fprintf(stderr, "Available filetypes: grb, nc, nc2, nc4, srv, ext and ieg\n");
+	      fprintf(stderr, "Available filetypes: grb, grb2, nc, nc2, nc4, srv, ext and ieg\n");
 	      exit(EXIT_FAILURE);
 	    }
 	  else
@@ -510,8 +520,8 @@ void setDefaultFileType(char *filetypestr, int labort)
 	    {
 	      fprintf(stderr, "Unexpected character >%c< in file type >%s<!\n", *ftstr, filetypestr);
 	      fprintf(stderr, "Use format[_nbits] with:\n");
-	      fprintf(stderr, "    format = grb, nc, nc2, nc4, srv, ext or ieg\n");
-	      fprintf(stderr, "    nbits  = 32/64 for nc, nc2, nc4, srv, ext, ieg; 1 - 32 for grb\n");
+	      fprintf(stderr, "    format = grb, grb2, nc, nc2, nc4, srv, ext or ieg\n");
+	      fprintf(stderr, "    nbits  = 32/64 for nc/nc2/nc4/srv/ext/ieg; 1 - 32 for grb/grb2\n");
 	      exit(EXIT_FAILURE);
 	    }
 	}
@@ -535,7 +545,7 @@ int cdoFiletype(void)
 #if  defined  (HAVE_LIBNETCDF)
 #include "netcdf.h"
 #endif
-
+static
 int have_netCDF4(void)
 {
   int haveNC4 = FALSE;
@@ -549,7 +559,7 @@ int have_netCDF4(void)
   return (haveNC4);
 }
 
-
+static
 void defineCompress(const char *arg)
 {
   size_t len = strlen(arg);
@@ -573,6 +583,56 @@ void defineCompress(const char *arg)
     fprintf(stderr, "Compression %s unsupported!\n", arg);
 }
 
+static
+void get_env_vars(void)
+{
+  char *envstr;
+
+  envstr = getenv("CDO_LOG_OFF");
+  if ( envstr )
+    {
+      if ( atoi(envstr) == 1 )
+	{
+	  cdoLogOff = TRUE;
+	  if ( cdoVerbose )
+	    fprintf(stderr, "CDO_LOG_OFF         = %s\n", envstr);
+	}
+    }
+
+  envstr = getenv("CDO_DISABLE_HISTORY");
+  if ( envstr )
+    {
+      if ( atoi(envstr) == 1 )
+	{
+	  cdoDisableHistory = TRUE;
+	  if ( cdoVerbose )
+	    fprintf(stderr, "CDO_DISABLE_HISTORY = %s\n", envstr);
+	}
+    }
+
+  envstr = getenv("CDO_DISABLE_FILESUFFIX");
+  if ( envstr )
+    {
+      if ( atoi(envstr) == 1 )
+	{
+	  cdoDisableFilesuffix = TRUE;
+	  if ( cdoVerbose )
+	    fprintf(stderr, "CDO_DISABLE_FILESUFFIX = %s\n", envstr);
+	}
+    }
+
+  envstr = getenv("CDO_DIAG");
+  if ( envstr )
+    {
+      if ( atoi(envstr) == 1 )
+	{
+	  cdoDiag = TRUE;
+	  if ( cdoVerbose )
+	    fprintf(stderr, "CDO_DIAG = %s\n", envstr);
+	}
+    }
+}
+
 
 int main(int argc, char *argv[])
 {
@@ -609,7 +669,7 @@ int main(int argc, char *argv[])
 
   cdoHaveNC4 = have_netCDF4();
 
-  while ( (c = cdoGetopt(argc, argv, "f:b:e:P:p:g:i:l:m:t:D:z:aBdhMRrsSTuVvZ")) != -1 )
+  while ( (c = cdoGetopt(argc, argv, "f:b:e:P:p:g:i:l:m:t:D:z:aBdhMQRrsSTuVvZ")) != -1 )
     {
       switch (c)
 	{
@@ -673,9 +733,12 @@ int main(int argc, char *argv[])
 	case 'p':
 	  setDefaultDataTypeByte(cdoOptarg);
 	  break;
+	case 'Q':
+	  cdiDefGlobal("SORTNAME", TRUE);
+	  break;
 	case 'R':
 	  cdoRegulargrid = TRUE;
-	  cdiDefGlobal("CD_REGULARGRID", TRUE);
+	  cdiDefGlobal("REGULARGRID", TRUE);
 	  break;
 	case 'r':
 	  cdoDefaultTimeType = TAXIS_RELATIVE;
@@ -714,53 +777,7 @@ int main(int argc, char *argv[])
 	}
     }
 
-  {
-      char *envstr;
-
-      envstr = getenv("CDO_LOG_OFF");
-      if ( envstr )
-	{
-	  if ( atoi(envstr) == 1 )
-	    {
-	      cdoLogOff = TRUE;
-	      if ( cdoVerbose )
-		fprintf(stderr, "CDO_LOG_OFF         = %s\n", envstr);
-	    }
-	}
-
-      envstr = getenv("CDO_DISABLE_HISTORY");
-      if ( envstr )
-	{
-	  if ( atoi(envstr) == 1 )
-	    {
-	      cdoDisableHistory = TRUE;
-	      if ( cdoVerbose )
-		fprintf(stderr, "CDO_DISABLE_HISTORY = %s\n", envstr);
-	    }
-	}
-
-      envstr = getenv("CDO_DISABLE_FILESUFFIX");
-      if ( envstr )
-	{
-	  if ( atoi(envstr) == 1 )
-	    {
-	      cdoDisableFilesuffix = TRUE;
-	      if ( cdoVerbose )
-		fprintf(stderr, "CDO_DISABLE_FILESUFFIX = %s\n", envstr);
-	    }
-	}
-
-      envstr = getenv("CDO_DIAG");
-      if ( envstr )
-	{
-	  if ( atoi(envstr) == 1 )
-	    {
-	      cdoDiag = TRUE;
-	      if ( cdoVerbose )
-		fprintf(stderr, "CDO_DIAG = %s\n", envstr);
-	    }
-	}
-  }
+  get_env_vars();
 
   if ( Debug || Version ) version();
 
@@ -970,6 +987,5 @@ int main(int argc, char *argv[])
 
   /* malloc_stats(); */
 
-
   return (status);
 }
