@@ -52,11 +52,16 @@ char *strdup(const char *s);
 
 
 /* sxxxYYYYMMDDhhmm0 */
-#define  DATE_LEN  16        /* allocate DTLEN+1 !!!! */
-#define  SET_DATE(dtstr, date, time)        (sprintf(dtstr, "%*d%*d", DATE_LEN-4, date, 4, time))
+#define  DATE_LEN  31        /* YYYYMMDDhhmmss allocate DTLEN+1 !!!! */
+#define  SET_DATE(dtstr, date, time)      (sprintf(dtstr, "%*d%*d", DATE_LEN-6, date, 6, time))
 #define  DATE_IS_NEQ(dtstr1, dtstr2, len) (memcmp(dtstr1, dtstr2, len) != 0)
 
 
+#if defined (__ibm__) /* performance problems on IBM */
+#ifndef DBL_IS_NAN
+#  define DBL_IS_NAN(x)     ((x) != (x))
+#endif
+#else
 #ifndef DBL_IS_NAN
 #if  defined  (HAVE_ISNAN)
 #  define DBL_IS_NAN(x)     (isnan(x))
@@ -66,6 +71,7 @@ char *strdup(const char *s);
 #  define DBL_IS_NAN(x)     ((x) != (x))
 #endif
 #endif
+#endif
 
 #ifndef DBL_IS_EQUAL
 /*#define DBL_IS_EQUAL(x,y) (!(x < y || y < x)) */
@@ -101,6 +107,10 @@ char *strdup(const char *s);
 #define CDO_EXP_LOCAL   1
 #define CDO_EXP_REMOTE  2
 
+#define DATE_FORMAT "%5.4d-%2.2d-%2.2d"
+#define TIME_FORMAT "%2.2d:%2.2d:%2.2d"
+
+
 enum {DATE_FIRST, DATE_LAST, DATE_MIDDLE};
 
 void strtolower(char *str);
