@@ -100,7 +100,7 @@ void intlinarr(int nxm, double *ym, double *xm, int nx, double *y, double *x)
   int j, jj;
 
   for ( jj = 1; jj < nxm; jj++ )
-    for ( j = 0; jj < nx; j++ )
+    for ( j = 0; j < nx; j++ )
       if ( x[j] >= xm[jj-1] && x[j] <= xm[jj] )
 	y[j] = intlin(x[j], ym[jj-1], xm[jj-1], ym[jj], xm[jj]);
 }
@@ -167,7 +167,7 @@ void intgrid(FIELD *field1, FIELD *field2)
 
 	  for ( ilat = 0; ilat < nlatIn; ilat++ )
 	    {
-	      fieldIn[ilat] = array + ilat*(nlonIn+1);;	  
+	      fieldIn[ilat] = array + ilat*(nlonIn+1);  
 	      memcpy(fieldIn[ilat], field[ilat], nlonIn*sizeof(double));
 	      fieldIn[ilat][nlonIn] = fieldIn[ilat][0];
 	      lonIn[nlonIn] = lonIn[0] + 360;
@@ -244,7 +244,7 @@ void intarea(FIELD *field1, FIELD *field2)
   double *planedat;
   double *lon_array, *lat_array, *lono_array, *lato_array;
   int irun;
-  int latfirst = 0, latlast;
+  int latfirst = 0, latlast = 0;
   int lonfirst = 0, lonlast;
 
   gridIDi    = field1->grid;
