@@ -43,6 +43,7 @@ void *Arithlat(void *argument);
 void *Cat(void *argument);
 void *CDItest(void *argument);
 void *Change(void *argument);
+void *Change_e5slm(void *argument);
 void *Comp(void *argument);
 void *Compc(void *argument);
 void *Cond(void *argument);
@@ -56,6 +57,7 @@ void *Echam5ini(void *argument);
 void *Enlarge(void *argument);
 void *Enlargegrid(void *argument);
 void *Ensstat(void *argument);
+void *Eofcoeff(void *argument);
 void *Timeof(void *argument);
 void *Expr(void *argument);
 void *Filedes(void *argument);
@@ -70,8 +72,9 @@ void *Gridcell(void *argument);
 void *Harmonic(void *argument);
 void *Histogram(void *argument);
 void *Importamsr(void *argument);
+void *Importbinary(void *argument);
 void *Importcmsaf(void *argument);
-void *Importgrads(void *argument);
+void *Importobs(void *argument);
 void *Info(void *argument);
 void *Input(void *argument);
 void *Intgrid(void *argument);
@@ -246,6 +249,7 @@ void *Wct(void *argument);
 #define  CatOperators           {"cat"}
 #define  CDItestOperators       {"ncopy"}
 #define  ChangeOperators        {"chcode", "chname", "chlevel", "chlevelc", "chlevelv", "chltype"}
+#define  Change_e5slmOperators  {"change_e5slm", "change_e5lsm", "change_e5mask"}
 #define  CompOperators          {"eq",  "ne",  "le",  "lt",  "ge",  "gt"}
 #define  CompcOperators         {"eqc", "nec", "lec", "ltc", "gec", "gtc"}
 #define  CondOperators          {"ifthen",  "ifnotthen"}
@@ -260,6 +264,7 @@ void *Wct(void *argument);
 #define  EnlargeOperators       {"enlarge"}
 #define  EnlargegridOperators   {"enlargegrid"}
 #define  EnsstatOperators       {"ensmin", "ensmax", "enssum", "ensmean", "ensavg", "ensvar", "ensstd", "enspctl"}
+#define  EofcoeffOperators      {"eofcoeff"}
 #define  TimeofOperators        {"eof", "eofspatial", "eoftime"}
 #define  ExprOperators          {"expr", "exprf", "aexpr", "aexprf"}
 #define  FiledesOperators       {"filedes", "griddes", "griddes2", "zaxisdes", "vct", "pardes", "taxisdes", "vlist", "partab", "partab2"}
@@ -275,8 +280,9 @@ void *Wct(void *argument);
 #define  HarmonicOperators      {"harmonic"}
 #define  HistogramOperators     {"histcount", "histsum", "histmean", "histfreq"}
 #define  ImportamsrOperators    {"import_amsr"}
+#define  ImportbinaryOperators  {"import_binary", "import_grads"}
 #define  ImportcmsafOperators   {"import_cmsaf"}
-#define  ImportgradsOperators   {"import_grads"}
+#define  ImportobsOperators     {"import_obs"}
 #define  InfoOperators          {"info", "infov", "map"}
 #define  InputOperators         {"input", "inputsrv", "inputext"}
 #define  IntgridOperators       {"intgridbil", "intpoint", "interpolate", "intarea", "boxavg", "thinout"}
@@ -305,14 +311,14 @@ void *Wct(void *argument);
 #define  NinfoOperators         {"nyear", "nmon", "ndate", "ntime", "ncode", "npar", "nlevel"}
 #define  NmltestOperators       {"nmltest"}
 #define  OutputOperators        {"output", "outputint", "outputsrv", "outputext", "outputf", "outputts", \
-                                 "outputfld", "outputarr"}
+                                 "outputfld", "outputarr", "outputxyz"}
 #define  OutputgmtOperators     {"gridverify", "outputcenter", "outputcenter2", "outputcentercpt", "outputbounds", \
                                  "outputboundscpt", "outputvector", "outputtri"}
 #define  PressureOperators      {"fpressure", "hpressure"}
 #define  PinfoOperators         {"pinfo", "pinfov"}
 #define  RegresOperators        {"regres"}
 #define  RemapOperators         {"remap"}
-#define    RemapgridOperators   {"remapcon", "remapbil", "remapbic", "remapdis", "remapnn", "remaplaf", "remapcon2"}
+#define    RemapgridOperators   {"remapcon", "remapbil", "remapbic", "remapdis", "remapnn", "remaplaf", "remapcon2", "remapsum"}
 #define    GenweightsOperators  {"gencon", "genbil", "genbic", "gendis", "gennn", "genlaf", "gencon2"}
 #define  RemapetaOperators      {"remapeta"}
 #define  ReplaceOperators       {"replace"}
@@ -339,7 +345,7 @@ void *Wct(void *argument);
 #define  SetgattOperators       {"setgatt", "setgatts"}
 #define  SetgridOperators       {"setgrid", "setgridtype", "setgridarea"}
 #define  SethaloOperators       {"sethalo", "tpnhalo"}
-#define  SetmissOperators       {"setmissval", "setctomiss", "setmisstoc", "setrtomiss"}
+#define  SetmissOperators       {"setmissval", "setctomiss", "setmisstoc", "setrtomiss", "setvrange"}
 #define  SetrangeOperators      {"setrtoc", "setrtoc2"}
 #define  SetrcanameOperators    {"setrcaname"}
 #define  SettimeOperators       {"setyear", "setmon", "setday", "setdate", "settime", "settunits", \
@@ -392,7 +398,7 @@ void *Wct(void *argument);
 #define  TrendOperators         {"trend"}
 #define  TrmsOperators          {"trms"}
 #define  VardupOperators        {"pardup", "parmul"}
-#define  VargenOperators        {"random", "const", "topo"}
+#define  VargenOperators        {"random", "const", "topo", "for"}
 #define  VarrmsOperators        {"varrms"}
 #define  VertintOperators       {"ml2pl", "ml2hl", "ml2plx", "ml2hlx", \
                                  "ml2pl_lp", "ml2hl_lp", "ml2plx_lp", "ml2hlx_lp"}
@@ -484,6 +490,7 @@ static MODULES Modules[] =
   { Cat,            CopyHelp,          CatOperators,           -1,  1 },
   { CDItest,        NULL,              CDItestOperators,        1,  1 },
   { Change,         ChangeHelp,        ChangeOperators,         1,  1 },
+  { Change_e5slm,   NULL,              Change_e5slmOperators,   1,  1 },
   { Comp,           CompHelp,          CompOperators,           2,  1 },
   { Compc,          CompcHelp,         CompcOperators,          1,  1 },
   { Cond,           CondHelp,          CondOperators,           2,  1 },
@@ -497,6 +504,7 @@ static MODULES Modules[] =
   { Enlarge,        EnlargeHelp,       EnlargeOperators,        1,  1 },
   { Enlargegrid,    NULL,              EnlargegridOperators,    1,  1 },
   { Ensstat,        EnsstatHelp,       EnsstatOperators,       -1,  1 },
+  { Eofcoeff,       NULL,              EofcoeffOperators,       2,  1 },
   { Timeof,         NULL,              TimeofOperators,         1,  2 },
   { Expr,           ExprHelp,          ExprOperators,           1,  1 },
   { Filedes,        FiledesHelp,       FiledesOperators,        1,  0 },
@@ -511,8 +519,9 @@ static MODULES Modules[] =
   { Harmonic,       NULL,              HarmonicOperators,       1,  1 },
   { Histogram,      HistogramHelp,     HistogramOperators,      1,  1 },
   { Importamsr,     ImportamsrHelp,    ImportamsrOperators,     1,  1 },
+  { Importbinary,   ImportbinaryHelp,  ImportbinaryOperators,   1,  1 },
   { Importcmsaf,    ImportcmsafHelp,   ImportcmsafOperators,    1,  1 },
-  { Importgrads,    NULL,              ImportgradsOperators,    1,  1 },
+  { Importobs,      NULL,              ImportobsOperators,      1,  1 },
   { Info,           InfoHelp,          InfoOperators,          -1,  0 },
   { Input,          InputHelp,         InputOperators,          0,  1 },
   { Intgrid,        IntgridHelp,       IntgridOperators,        1,  1 },
