@@ -1,4 +1,25 @@
 
+#define  RESTR_TYPE  int  /* restrict data types: 0 -> double, float; 1 -> int */
+
+typedef RESTR_TYPE restr_t;
+/*
+#if RESTR_TYPE == int
+#  define RESTR_SCALE(x) ((int) (0.5+100000000*(x)))
+#  define RESTR_ABS(x)   abs(x)
+#else
+#  define RESTR_SCALE(x) (x)
+#  define RESTR_ABS(x)   fabs(x)
+#endif
+*/
+
+#  define RESTR_SFAC     100000000
+#  define RESTR_SCALE(x) ((int) (0.5+RESTR_SFAC*(x)))
+#  define RESTR_ABS(x)   abs(x)
+/*
+#  define RESTR_SFAC     1.
+#  define RESTR_SCALE(x) (x)
+#  define RESTR_ABS(x)   fabs(x)
+*/
 
 #define  NORM_OPT_NONE      1
 #define  NORM_OPT_DESTAREA  2
@@ -12,6 +33,7 @@
 
 #define  SUBMAP_TYPE_NONE   0
 #define  SUBMAP_TYPE_LAF    1
+#define  SUBMAP_TYPE_SUM    2
 
 #define  RESTRICT_LATITUDE  1
 #define  RESTRICT_LATLON    2
@@ -24,9 +46,9 @@ typedef struct {
   int      lextrapolate;
   int      non_global;
   int      grid1_is_cyclic, grid2_is_cyclic;
-  int      grid1_size, grid2_size; /* total points on each grid */
+  long     grid1_size, grid2_size; /* total points on each grid */
   int      grid1_rank, grid2_rank; /* rank of each grid */
-  int      grid1_corners, grid2_corners; /* number of corners for each grid cell */
+  long     grid1_corners, grid2_corners; /* number of corners for each grid cell */
 
   int      grid1_dims[2], grid2_dims[2]; /* size of each grid dimension */
 
@@ -62,8 +84,8 @@ typedef struct {
   /* int      luse_grid1_area;   */ /* use area from grid file         */
   /* int      luse_grid2_area;   */ /* use area from grid file         */
 
-  double  *grid1_bound_box;    /* lat/lon bounding box for use    */
-  double  *grid2_bound_box;    /* in restricting grid searches    */
+  restr_t *grid1_bound_box;    /* lat/lon bounding box for use    */
+  restr_t *grid2_bound_box;    /* in restricting grid searches    */
 
   int      restrict_type;
   int      num_srch_bins;      /* num of bins for restricted srch */
@@ -71,8 +93,8 @@ typedef struct {
   int     *bin_addr1;       /* min,max adds for grid1 cells in this lat bin  */
   int     *bin_addr2;       /* min,max adds for grid2 cells in this lat bin  */
 
-  double  *bin_lats;        /* min,max latitude for each search bin   */
-  double  *bin_lons;        /* min,max longitude for each search bin  */
+  restr_t *bin_lats;        /* min,max latitude for each search bin   */
+  restr_t *bin_lons;        /* min,max longitude for each search bin  */
 }
 remapgrid_t;
 
@@ -89,9 +111,9 @@ remaplink_t;
 
 typedef struct {
   int   pinit;            /* TRUE if the pointers are initialized     */
-  int   max_links;        /* current size of link arrays              */
-  int   num_links;        /* actual number of links for remapping     */
-  int   num_wts;          /* num of weights used in remapping         */
+  long  max_links;        /* current size of link arrays              */
+  long  num_links;        /* actual number of links for remapping     */
+  long  num_wts;          /* num of weights used in remapping         */
   int   map_type;         /* identifier for remapping method          */
   int   norm_opt;         /* option for normalization (conserv only)  */
   int   resize_increment; /* default amount to increase array size    */
@@ -114,7 +136,7 @@ typedef struct {
 }
 remap_t;
 
-void remap_set_max_iter(int max_iter);
+void remap_set_max_iter(long max_iter);
 
 void remapGridInit(int map_type, int lextrapolate, int gridID1, int gridID2, remapgrid_t *rg);
 void remapVarsInit(int map_type, remapgrid_t *rg, remapvars_t *rv);
@@ -122,14 +144,16 @@ void remapVarsInit(int map_type, remapgrid_t *rg, remapvars_t *rv);
 void remapVarsFree(remapvars_t *rv);
 void remapGridFree(remapgrid_t *rg);
 
-void remap(double *dst_array, double missval, int dst_size, int dst_array_dim,
-	   double **map_wts, int map_wts_dim,
-	   int *dst_add, int *src_add, 
-	   double *src_array, double *src_grad1, double *src_grad2, double *src_grad3,
+void remap(double *dst_array, double missval, long dst_size, long num_links, double **map_wts, 
+	   long num_wts, const int *dst_add, const int *src_add, const double *src_array, 
+	   const double *src_grad1, const double *src_grad2, const double *src_grad3,
 	   remaplink_t links);
 
-void remap_laf(double *dst_array, double missval, int dst_size, int num_links, double **map_wts,
-	       int *dst_add, int *src_add, double *src_array);
+void remap_laf(double *dst_array, double missval, long dst_size, long num_links, double **map_wts,
+	       const int *dst_add, const int *src_add, const double *src_array);
+
+void remap_sum(double *dst_array, double missval, long dst_size, long num_links, double **map_wts,
+	       const int *dst_add, const int *src_add, const double *src_array);
 
 void remap_bilin(remapgrid_t *rg, remapvars_t *rv);
 void remap_bicub(remapgrid_t *rg, remapvars_t *rv);
@@ -139,13 +163,14 @@ void remap_distwgt1(remapgrid_t *rg, remapvars_t *rv);
 
 void resize_remap_vars(remapvars_t *rv, int increment);
 
-void remap_stat(int remap_order, remapgrid_t rg, remapvars_t rv, double *array1, double *array2, double missval);
-void remap_gradients(remapgrid_t rg, double *array, double *grad1_lat,
-		     double *grad1_lon, double *grad1_latlon);
+void remap_stat(int remap_order, remapgrid_t rg, remapvars_t rv, const double *array1, 
+		const double *array2, double missval);
+void remap_gradients(remapgrid_t rg, const double *array, double * restrict grad1_lat,
+		     double * restrict grad1_lon, double * restrict grad1_latlon);
 
 void reorder_links(remapvars_t *rv);
 
-void sort_add(int num_links, int num_wts, int *add1, int *add2, double **weights);
+void sort_add(long num_links, long num_wts, int * restrict add1, int * restrict add2, double ** restrict weights);
 
 void write_remap_scrip(const char *interp_file, int map_type, int submap_type, 
 		       int remap_order, remapgrid_t rg, remapvars_t rv);
